@@ -133,15 +133,22 @@ get_ned <- function(template,
 #' @keywords internal
 download_ned_tile <- function(res = "1", tileNorthing, tileWesting, raw.dir) {
   
-  destdir <- paste(raw.dir, "/", res, sep = "")
+  destdir <- paste(raw.dir, "/", res, "/", sep = "")
   
   dir.create(destdir, showWarnings = FALSE, recursive = TRUE)
   
   tileWesting <- formatC(tileWesting, width = 3, format = "d", flag = "0")
   tileNorthing <- formatC(tileNorthing, width = 2, format = "d", flag = "0")
-  url <- paste0("https://prd-tnm.s3.amazonaws.com/StagedProducts/Elevation/", res, "/ArcGrid/n", tileNorthing, "w", tileWesting, 
+
+  url <- paste0("https://prd-tnm.s3.amazonaws.com/StagedProducts/Elevation/", res, "/ArcGrid/USGS_NED_",res,"_n", tileNorthing, "w", tileWesting, 
+                "_ArcGrid.zip")
+  
+  # USGS is in the process of updating all of their URLs for the NED.
+  # If the new URL doesn't exist, try the old one.
+  if(httr::http_error(url))
+    url <- paste0("https://prd-tnm.s3.amazonaws.com/StagedProducts/Elevation/", res, "/ArcGrid/n", tileNorthing, "w", tileWesting, 
                 ".zip")
-  destdir <- paste(raw.dir, "/", res, "/", sep = "")
+  
   download_data(url = url, destdir = destdir)
   
   return(normalizePath(paste0(destdir, basename(url))))
