@@ -1,4 +1,4 @@
 library(testthat)
 library(FedData)
 
-#test_check("FedData")
+test_check("FedData")
